/* 31 January 2012, copyright R.Harmsen:

   Remove any ASCII from stdin, so all that remains
   is, for example, Arabic coded as UTF-8.
   Spaces, tabs and newlines however are left intact,
   because they can also be used in languages like
   Arabic.

   Moreover, any whitespace characters (spaces, tabs,
   returns and newlines) and punctuation (stop, comma,
   colon, semicolon etc.) are converted to a single
   newline, to get simpler files with one word per
   line.

   The purpose of this is to check HTML text files
   after manipulations, e.g. with a text editor,
   stream editor or other program. Especially useful
   if you can't read the language in question yourself,
   so any mistakes that could have mangled the text
   (caused by unexpected technical complications) would
   go unnoticed.

   After creating reduced files with this utility,
   it is much easier to compare files before and after
   some change, using the usual tools such as ``diff''.
*/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <ctype.h>
#include <math.h>

int main (int argc, char **argv)
{
   int c, p = '\0';

   while ((c = getc(stdin)) != EOF)
   {
       if (isascii(c) || isspace(c) || ispunct(c))
          c = '\n';

       if (c == '\n' && p == '\n')
          continue;

       putc(c, stdout);
       p = c;
   }

   return 0;
}
